import { Config } from "@/config";
import type { Options } from "@/options";
import { ServiceCapture, ServiceStore, ServicePublish } from "@/service";
import { InternalHandlers } from "@/service/tiki/internal-handlers";
/**
 * The main entry point for interacting with service-level (non-UI) functionality.
 * Access the service methods using [Vue3 injection](https://vuejs.org/guide/components/provide-inject.html)
 * with the key `"Tiki"`
 *
 * @example
 * ```
 * <script setup lang="ts">
 * const tiki: TikiService | undefined = inject("Tiki");
 * </script>
 * ```
 */
export declare class TikiService {
    /**
     * @ignore
     */
    readonly config: Config;
    /**
     * @ignore
     */
    readonly capture: ServiceCapture;
    /**
     * @ignore
     */
    readonly store: ServiceStore;
    /**
     * @ignore
     */
    readonly internalHandlers: InternalHandlers;
    /**
     * @ignore
     */
    readonly publish: ServicePublish;
    /**
     * @ignore
     */
    private _isInitialized;
    /**
     * @ignore
     */
    constructor(options: Options);
    /**
     * Get the initialization status of the service.
     * @returns `true` if the service is initialized, `false` otherwise.
     */
    get isInitialized(): boolean;
    /**
     * Initialize the service for a specified user.
     * @param id - The user's unique identifier.
     * @returns A Promise that resolves when the initialization is complete.
     */
    initialize(id: string): Promise<void>;
    /**
     * Log the user out of all linked accounts, remove all credentials,
     * clear stored preferences, and in-memory service cache.
     * @returns A Promise that resolves when the logout is complete.
     */
    logout(): Promise<void>;
}
